@@ -8,12 +8,12 @@ from conans.client.graph.grapher import Grapher
 from conans.client.installer import build_id
 from conans.client.printer import Printer
 from conans.model.ref import ConanFileReference, PackageReference
+from conans.paths.package_layouts.package_editable_layout import PackageEditableLayout
 from conans.search.binary_html_table import html_binary_graph
-from conans.unicode import get_cwd
 from conans.util.dates import iso8601_to_str
-from conans.util.env_reader import get_env
 from conans.util.files import save
 from conans import __version__ as client_version
+from conans.util.misc import make_tuple
 
 
 class CommandOutputer(object):
@@ -63,13 +63,13 @@ class CommandOutputer(object):
         if json_output is True:  # To the output
             self._output.write(json_str)
         else:  # Path to a file
-            cwd = os.path.abspath(cwd or get_cwd())
+            cwd = os.path.abspath(cwd or os.getcwd())
             if not os.path.isabs(json_output):
                 json_output = os.path.join(cwd, json_output)
             save(json_output, json_str)
 
     def json_output(self, info, json_output, cwd):
-        cwd = os.path.abspath(cwd or get_cwd())
+        cwd = os.path.abspath(cwd or os.getcwd())
         if not os.path.isabs(json_output):
             json_output = os.path.join(cwd, json_output)
 
@@ -120,6 +120,7 @@ class CommandOutputer(object):
         build_time_nodes = deps_graph.build_time_nodes()
         remotes = self._cache.registry.load_remotes()
         ret = []
+
         for (ref, package_id), list_nodes in compact_nodes.items():
             node = list_nodes[0]
             if node.recipe == RECIPE_VIRTUAL:
@@ -137,21 +138,33 @@ class CommandOutputer(object):
             item_data["display_name"] = conanfile.display_name
             item_data["id"] = package_id
             item_data["build_id"] = build_id(conanfile)
+            item_data["context"] = conanfile.context
+
+            python_requires = getattr(conanfile, "python_requires", None)
+            if python_requires and not isinstance(python_requires, dict):  # no old python requires
+                item_data["python_requires"] = [repr(r)
+                                                for r in conanfile.python_requires.all_refs()]
 
             # Paths
             if isinstance(ref, ConanFileReference) and grab_paths:
                 package_layout = self._cache.package_layout(ref, conanfile.short_paths)
-                item_data["export_folder"] = package_layout.export()
-                item_data["source_folder"] = package_layout.source()
-                pref_build_id = build_id(conanfile) or package_id
-                pref = PackageReference(ref, pref_build_id)
-                item_data["build_folder"] = package_layout.build(pref)
-
-                pref = PackageReference(ref, package_id)
-                item_data["package_folder"] = package_layout.package(pref)
+                if isinstance(package_layout, PackageEditableLayout):  # Avoid raising exception
+                    item_data["export_folder"] = conanfile.recipe_folder
+                    item_data["source_folder"] = conanfile.source_folder  # This is None now
+                    item_data["build_folder"] = conanfile.build_folder  # This is None now
+                    item_data["package_folder"] = conanfile.package_folder  # This is None now
+                else:
+                    item_data["export_folder"] = package_layout.export()
+                    item_data["source_folder"] = package_layout.source()
+                    pref_build_id = build_id(conanfile) or package_id
+                    pref = PackageReference(ref, pref_build_id)
+                    item_data["build_folder"] = package_layout.build(pref)
+                    pref = PackageReference(ref, package_id)
+                    item_data["package_folder"] = package_layout.package(pref)
 
             try:
-                reg_remote = self._cache.package_layout(ref).load_metadata().recipe.remote
+                package_metadata = self._cache.package_layout(ref).load_metadata()
+                reg_remote = package_metadata.recipe.remote
                 reg_remote = remotes.get(reg_remote)
                 if reg_remote:
                     item_data["remote"] = {"name": reg_remote.name, "url": reg_remote.url}
@@ -164,8 +177,7 @@ class CommandOutputer(object):
                     if not as_list:
                         item_data[attrib] = value
                     else:
-                        item_data[attrib] = list(value) if isinstance(value, (list, tuple, set)) \
-                            else [value, ]
+                        item_data[attrib] = make_tuple(value)
 
             _add_if_exists("url")
             _add_if_exists("homepage")
@@ -173,12 +185,15 @@ class CommandOutputer(object):
             _add_if_exists("author")
             _add_if_exists("description")
             _add_if_exists("topics", as_list=True)
+            _add_if_exists("deprecated")
+            _add_if_exists("provides", as_list=True)
+            _add_if_exists("scm")
 
             if isinstance(ref, ConanFileReference):
                 item_data["recipe"] = node.recipe
 
-                if get_env("CONAN_CLIENT_REVISIONS_ENABLED", False) and node.ref.revision:
-                    item_data["revision"] = node.ref.revision
+                item_data["revision"] = node.ref.revision
+                item_data["package_revision"] = node.prev
 
                 item_data["binary"] = node.binary
                 if node.binary_remote:
