@@ -8,6 +8,7 @@ from six import string_types
 
 from conans.client import tools
 from conans.client.output import ScopedOutput
+from conans.client.subsystems import command_env_wrapper
 from conans.client.tools.env import environment_append, no_op, pythonpath
 from conans.client.tools.oss import OSInfo
 from conans.errors import ConanException, ConanInvalidConfiguration
@@ -141,6 +142,7 @@ class ConanFile(object):
 
     # Run in windows bash
     win_bash = None
+    tested_reference_str = None
 
     def __init__(self, output, runner, display_name="", user=None, channel=None):
         # an output stream (writeln, info, warn error)
@@ -173,9 +175,9 @@ class ConanFile(object):
         self.cpp.package.includedirs = ["include"]
         self.cpp.package.libdirs = ["lib"]
         self.cpp.package.bindirs = ["bin"]
-        self.cpp.package.resdirs = ["res"]
+        self.cpp.package.resdirs = []
         self.cpp.package.builddirs = [""]
-        self.cpp.package.frameworkdirs = ["Frameworks"]
+        self.cpp.package.frameworkdirs = []
 
     @property
     def context(self):
@@ -247,12 +249,26 @@ class ConanFile(object):
     def new_cpp_info(self):
         if not self._conan_new_cpp_info:
             self._conan_new_cpp_info = from_old_cppinfo(self.cpp_info)
+            # The new_cpp_info will be already absolute paths if layout() is defined
+            if self.package_folder is not None:  # to not crash when editable and layout()
+                self._conan_new_cpp_info.set_relative_base_folder(self.package_folder)
         return self._conan_new_cpp_info
 
     @property
     def source_folder(self):
         return self.folders.source_folder
 
+    @property
+    def export_sources_folder(self):
+        """points to the base source folder when calling source() and to the cache export sources
+        folder while calling the exports_sources() method. Prepared in case we want to introduce a
+        'no_copy_export_sources' and point to the right location always."""
+        return self.folders.base_export_sources
+
+    @property
+    def export_folder(self):
+        return self.folders.base_export
+
     @property
     def build_folder(self):
         return self.folders.build_folder
@@ -363,7 +379,7 @@ class ConanFile(object):
         """
 
     def run(self, command, output=True, cwd=None, win_bash=False, subsystem=None, msys_mingw=True,
-            ignore_errors=False, run_environment=False, with_login=True, env=None):
+            ignore_errors=False, run_environment=False, with_login=True, env="conanbuild"):
         # NOTE: "self.win_bash" is the new parameter "win_bash" for Conan 2.0
 
         def _run(cmd, _env):
@@ -372,13 +388,9 @@ class ConanFile(object):
                 if win_bash:
                     return tools.run_in_windows_bash(self, bashcmd=cmd, cwd=cwd, subsystem=subsystem,
                                                      msys_mingw=msys_mingw, with_login=with_login)
-                elif self.win_bash:  # New, Conan 2.0
-                    from conan.tools.microsoft.subsystems import run_in_windows_bash
-                    return run_in_windows_bash(self, command=cmd, cwd=cwd, env=_env)
-            if _env is None:
-                _env = "conanbuild"
-            from conan.tools.env.environment import environment_wrap_command
-            wrapped_cmd = environment_wrap_command(_env, cmd, cwd=self.generators_folder)
+            envfiles_folder = self.generators_folder or os.getcwd()
+            _env = [_env] if _env and isinstance(_env, str) else []
+            wrapped_cmd = command_env_wrapper(self, cmd, _env, envfiles_folder=envfiles_folder)
             return self._conan_runner(wrapped_cmd, output, os.path.abspath(RUN_LOG_NAME), cwd)
 
         if run_environment:
